#
# spec file for package freetype
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           freetype
BuildRequires:  autoconf
BuildRequires:  xorg-x11-devel
# bug437293
%ifarch ppc64
Obsoletes:      freetype-64bit
%endif
#
PreReq:         fileutils
Version:        1.3.1
Release:        1418.4
Url:            http://www.freetype.org
Summary:        TrueType Font Engine
License:        SUSE-Freetype or GPL-2.0+
Group:          System/Libraries
Source:         ftp://ftp.freetype.org/pub/freetype1/freetype-%{version}.tar.bz2
Source2:        baselibs.conf
Patch0:         freetype-tools-1.3.1.patch
Patch1:         freetype-%{version}.dif
Patch2:         freetype-%{version}-nopatent.patch
Patch3:         freetype-%{version}-gcc.patch
Patch4:         freetype-%{version}-kpathsea.patch
Patch5:         update-config-files.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A library for working with TrueType Fonts. Documentation is in the
/usr/share/doc/packages/freetype directory.

%package -n libttf2
Summary:        TrueType Font Engine
Group:          System/Libraries

%description -n libttf2
A library for working with TrueType Fonts. Documentation is in the
/usr/share/doc/packages/freetype directory.

%package devel
Summary:        Development files for the TrueType Font Engine
Group:          Development/Libraries/C and C++
Requires:       libttf2 = %version

%description devel
A library for working with TrueType Fonts. Documentation is in the
/usr/share/doc/packages/freetype directory.

%package -n freetype-tools
Summary:        Bundled Tests, Demos and Tools for FreeType  (Needed for CJK-LaTeX)
Group:          Development/Libraries/C and C++
Requires:       freetype
Recommends:     texlive-ttfutils

%description -n freetype-tools
Bundled tests, demos and tools for FreeType. Needed for CJK-LaTeX.

The FreeType engine is a free and portable TrueType font rendering
engine. It has been developed to provide TT support to a great variety
of platforms and environments.

This package contains several programs bundled with the FreeType engine
for testing and demonstration purposes as well as some contributed
utilities, such as ttf2bdf, ttf2pfb, and ttfbanner.

%prep
%setup
%patch0 -p1
%patch1
%patch2
%patch3
%patch4
%patch5 -p1

%build
# fix build with newer glibc
sed "s:getline:getline_nonlibc:" -i contrib/*/*.{c,h}
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" 

# Neither %%configure nor %%_smp_mflags is supported in this package..
./configure --prefix=/usr \
                   --with-locale-dir=/usr/share/locale \
		   --libdir=%{_libdir} \
                   %{_target_cpu}-suse-linux-gnu
make 
pushd contrib/ttf2bdf
    ./configure --prefix=/usr --mandir=$RPM_BUILD_ROOT%{_mandir} \
	        --libdir=%{_libdir} \
		%{_target_cpu}-suse-linux-gnu
    make
popd
pushd contrib/ttf2pfb
    ./configure --prefix=/usr --mandir=$RPM_BUILD_ROOT%{_mandir} \
		--libdir=%{_libdir} \
		%{_target_cpu}-suse-linux-gnu
    make
popd
pushd contrib/ttfbanner
    ./configure --prefix=/usr --mandir=$RPM_BUILD_ROOT%{_mandir} \
		--libdir=%{_libdir} \
		%{_target_cpu}-suse-linux-gnu
    make
popd

%install
make prefix=$RPM_BUILD_ROOT/usr \
     libdir=$RPM_BUILD_ROOT/%{_libdir} \
     gnulocaledir=$RPM_BUILD_ROOT/usr/share/locale \
     localedir=$RPM_BUILD_ROOT/usr/share/locale  install
for i in ttf2bdf ttf2pfb ttfbanner; do
    make -C contrib/$i prefix=$RPM_BUILD_ROOT/usr install
done
# copy documentation for freetype-tools:
mkdir -p freetype-tools-doc/ttf2bdf
mkdir -p freetype-tools-doc/ttf2pfb
mkdir -p freetype-tools-doc/ttfbanner
cp contrib/ttf2bdf/README freetype-tools-doc/ttf2bdf
cp contrib/ttf2pfb/TODO freetype-tools-doc/ttf2pfb
cp contrib/ttfbanner/README freetype-tools-doc/ttfbanner
pushd $RPM_BUILD_ROOT/usr/bin
    # rename the utility programs to avoid the name conflict with the same
    # utilities from freetype2:
    rename ft ft1 ft* 
popd
pushd $RPM_BUILD_ROOT/usr/include/freetype
    # Creeate extend sub directory and link all ftx*.h into this directory
    mkdir extend
    cd extend/
    ln -sf ../ftx*.h .
popd
# don't pack t1asm, because this file is in package t1utils:
rm -f $RPM_BUILD_ROOT/usr/bin/t1asm
# don't pack getafm, because it is in the package psutils:
rm -f $RPM_BUILD_ROOT/usr/bin/getafm
rm -f "%buildroot/%_libdir"/*.la
%find_lang %{name}

%post -n libttf2 -p /sbin/ldconfig

%postun -n libttf2 -p /sbin/ldconfig

%post -n freetype-tools
mkdir -p var/adm/SuSEconfig ; touch var/adm/SuSEconfig/run-texhash
test -x usr/bin/texhash && usr/bin/texhash
exit 0

%postun -n freetype-tools
mkdir -p var/adm/SuSEconfig ; touch var/adm/SuSEconfig/run-texhash
test -x usr/bin/texhash && usr/bin/texhash
exit 0

%files -f %{name}.lang
%defattr(-,root,root)
%doc README license.txt docs/FAQ docs/TODO docs/*.txt
/usr/bin/ft1view
/usr/bin/ft1timer
/usr/bin/ft1lint
/usr/bin/ft1dump
/usr/bin/ft1zoom
/usr/bin/ft1string
/usr/bin/ft1strpnm
/usr/bin/ft1error
/usr/bin/ft1metric
/usr/bin/ft1sbit
/usr/bin/ft1strtto

%files -n libttf2
%defattr(-,root,root)
%{_libdir}/libttf.so.2
%{_libdir}/libttf.so.2.2.0

%files devel
%defattr(-,root,root)
/usr/include/freetype
/usr/include/freetype/extend
%{_libdir}/libttf.so

%files -n freetype-tools
%defattr(-, root, root)
%doc ./freetype-tools-doc
/usr/bin/ttf2bdf
/usr/bin/ttf2pfb
/usr/bin/ttfbanner
/usr/share/man/man1/ttf2bdf.1.gz

%changelog
* Mon Aug 18 2014 fcrozat@suse.com
- Add obsoletes/provides to baselibs.conf for library package.
* Mon Jul 30 2012 coolo@suse.com
- do not package ttf2$TEX - the source in texlive is more uptodate
* Tue Feb 14 2012 cfarrell@suse.com
- license update: SUSE-Freetype or GPL-2.0+
* Sun Feb  5 2012 jengelh@medozas.de
- Split main package into libttf2 (shared library policy) and
  a devel subpackage
* Thu Dec 22 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Tue Dec 20 2011 coolo@suse.com
- replace suse_update_config with patch to update the files,
  this package really needs to disappear soon
* Sun Dec 19 2010 aj@suse.de
- Fix declaration of kpathsea_version_string.
* Sun Jan 31 2010 jengelh@medozas.de
- package baselibs.conf
* Fri Jun  5 2009 nadvornik@suse.cz
- fixed to build with the new glibc
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  2 2008 crrodriguez@suse.de
- fix file-not-in-lang rpmlint errors
* Wed May 16 2007 mfabian@suse.de
- adapt /etc/ttf2pk/ttfonts.map to the changes in the cjk-latex
  font setup for the Arphic fonts needed for texlive.
* Sun Apr 22 2007 ro@suse.de
- use texlive-devel for building
* Wed Aug 16 2006 werner@suse.de
- Create extend sub dir under freetype include dir to support this
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Feb 25 2005 mfabian@suse.de
- add entries to /etc/ttf2pk/ttfonts.map to support the use of the
  IPA fonts.
* Fri Oct 15 2004 mfabian@suse.de
- add entries to /etc/ttf2pk/ttfonts.map to support the use of the
  Novell-ricoh-fonts.
* Fri Oct  1 2004 mfabian@suse.de
- add entries to /etc/ttf2pk/ttfonts.map to support the use of the
  Sazanami fonts (which replaced the dropped Kochi fonts) with
  CJK-LaTeX.
* Mon Apr 26 2004 mfabian@suse.de
- Bugzilla #39459: add entries to /etc/ttf2pk/ttfonts.map to
  support the use of the Chinese "Founder" fonts with CJK-LaTeX.
* Tue Feb 10 2004 nadvornik@suse.cz
- compiled with -fno-strict-aliasing
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Sun Aug 24 2003 mfabian@suse.de
- add entries to /etc/ttf2pk/ttfonts.map to support the use of
  the Mika-Chan fonts with CJK-LaTeX.
* Fri Jun 13 2003 kukuk@suse.de
- add missing directories to filelist
* Wed May 28 2003 nadvornik@suse.cz
- remove/install unpackaged files from buildroot
* Sat Jan 25 2003 mfabian@suse.de
- rename the utilities to avoid the name conflict with  the same
  utilities from freetype2: ftdump -> ft1dump, ftview -> ft1view
  etc ...
* Tue Nov 26 2002 nadvornik@suse.cz
- fixed to compile with new gcc
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Aug  5 2002 nadvornik@suse.cz
- added PreReq: fileutils
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Wed Jun 12 2002 ro@suse.de
- hack ltconfig for ppc64
* Thu Apr 11 2002 nadvornik@suse.cz
- fixed to build with new gcc
* Wed Feb 13 2002 nadvornik@suse.cz
- used macro %%{_libdir}
* Mon Dec 10 2001 schwab@suse.de
- Fix undefined operation in ttf2bdf.
- Fix configuration of ttf2pk: don't add /usr/include to search path.
* Sat Oct  6 2001 mfabian@suse.de
- add entries to /etc/ttf2pk/ttfonts.map to support the use of
  the Kochi, the Baekmuk, and the Arphic PL fonts in UTF-8
  encoding with CJK-LaTeX.
* Tue Aug  7 2001 mfabian@suse.de
- add entries to /etc/ttf2pk/ttfonts.map to support the free
  Japanese TrueType fonts kochi-mincho.ttf and
  kochi-gothic.ttf from the ttf-kochi-mincho and ttf-kochi-gothic
  packages (needed by the cjk-latex-package)
* Mon May  7 2001 mfabian@suse.de
- bzip2 sources
* Fri Mar 16 2001 nadvornik@suse.cz
- disabled compilation of bytecode interpreter
* Sun Mar  4 2001 schwab@suse.de
- Don't use uninitialized data in ttf2tfm.
- Default to RPM_OPT_FLAGS in all compilations.
* Thu Feb 15 2001 mfabian@suse.de
- add entries to /etc/ttf2pk/ttfonts.map to support the free
  Japanese TrueType fonts watanabe-mincho.ttf and
  wadalab-gothic.ttf from the xtt-fonts package (needed by the
  cjk-latex-package)
* Sun Jan 21 2001 mfabian@suse.de
- add entries to /etc/ttf2pk/ttfonts.map to support the
  Korean Baekmuk TrueType fonts (needed by the cjk-latex package).
- mark ttfonts.map with %%config in spec file
* Fri Dec  8 2000 mfabian@suse.de
- don't pack getafm, because it is in the package psutils,
  packing it here would result in a conflict.
* Mon Dec  4 2000 mfabian@suse.de
- don't pack /usr/bin/t1asm, because this file is in the
  package t1utils, packing it here to would result in a conflict.
* Mon Dec  4 2000 mfabian@suse.de
- added entries for the Bitstream Cyberbit True Type fonts
  and Microsofts Japanese True Type fonts msmincho.ttc and
  msgothic.ttc to ttfonts.map
* Thu Nov 30 2000 mfabian@suse.de
- make new sub-package "freetype-tools".
  I choose this name because the equivalent Debian package has
  this name. This sub package contains some tools for FreeType
  which are needed by CJK-LaTeX.
- included the Debian patches by Anthony Fok <foka@debian.org>
  for ttfonts.map and UBig5.sfd which make changes necessary
  to use the free Arphic PL fonts for Chinese.
- also included the Debian patch to fix a va_arg problem
  which prevents the build on powerpc.
* Thu Apr 27 2000 nadvornik@suse.cz
- changed Group tag
* Mon Apr 10 2000 nadvornik@suse.cz
- fixed URL
* Fri Apr  7 2000 bk@suse.de
- added suse update config macro
* Tue Apr  4 2000 nadvornik@suse.cz
- added BuildRoot
- added URL
* Wed Jan 19 2000 ro@suse.de
- update to 1.3.1
- includes now in /usr/include/freetype
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jun 28 1999 ro@suse.de
- update to 1.2
* Mon Jun 29 1998 ro@suse.de
- update to version 1.1
* Tue Mar 10 1998 ro@suse.de
- added include file
* Mon Mar  9 1998 ro@suse.de
- created new package / uses gettext / version 1.0
